<?php
/*
Plugin Name: Donation Link Manager
Plugin URI: http://wpgogo.com/development/donation-link-manager.html
Description: This plugin adds a donation link banner on your site especially for Japan Earthquake and Tsunami relief.
Author: Hiroaki Miyashita
Version: 1.0.2
Author URI: http://wpgogo.com/
*/

/*  Copyright 2011 Hiroaki Miyashita

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

class donation_link_manager {

	function donation_link_manager() {
		add_action( 'init', array(&$this, 'donation_link_manager_init') );
		add_action( 'admin_print_scripts', array(&$this, 'donation_link_manager_admin_scripts') );
		add_action( 'admin_menu', array(&$this, 'donation_link_manager_admin_menu') );
		add_filter( 'plugin_action_links', array(&$this, 'donation_link_manager_plugin_action_links'), 10, 2 );
		add_action( 'wp_footer', array(&$this, 'donation_link_manager_wp_footer'), 1000 );
	}
		
	function donation_link_manager_init() {
		global $current_user;

		if ( function_exists('load_plugin_textdomain') ) :
			if ( !defined('WP_PLUGIN_DIR') ) 
				load_plugin_textdomain('donation-link-manager', str_replace( ABSPATH, '', dirname(__FILE__) ) );
			else
				load_plugin_textdomain('donation-link-manager', false, dirname( plugin_basename(__FILE__) ) );
		endif;
		
		if( strstr($_SERVER['REQUEST_URI'], 'wp-admin/plugins.php') && ((isset($_GET['activate']) && $_GET['activate'] == 'true') || (isset($_GET['activate-multi']) && $_GET['activate-multi'] == 'true') ) ) :
			$options = get_option('donation_link_manager_data');
			if( empty($options) ) :
				$this->install_donation_link_manager_data(WPLANG);
			endif;
		endif;
		
		$this->donation_link_manager_action();
	}
	
	function install_donation_link_manager_data($wplang = '') {
		$options['design'] = 0;
		$options['height'] = 70;
		$options['width']  = 900;
		$options['position']  = 'center';
		
		if ( $wplang == 'ja' ) :
			$options['background'][] = get_option('siteurl') . '/' . PLUGINDIR . '/donation-link-manager/images/background1.png';
			$options['banner'][] = get_option('siteurl') . '/' . PLUGINDIR . '/donation-link-manager/images/banner1.png';
		
			$options['name'][] = '日本赤十字社 （Japanese）';
			$options['url'][]  = 'http://www.jrc.or.jp/contribution/l3/Vcms3_00002069.html';

			$options['name'][] = 'JustGiving （Japanese）';
			$options['url'][]  = 'http://justgiving.jp/c/?sort=donate_sum';

			$options['name'][] = '日本財団 （Japanese）';
			$options['url'][]  = 'http://canpan.info/open/news/0000006465/news_detail.html';

			$options['name'][] = 'Yahoo!JAPAN （Japanese）';
			$options['url'][]  = 'http://bokin.yahoo.co.jp/donation/detail/1630001/';

			$options['name'][] = 'Google （Japanese）';
			$options['url'][]  = 'http://www.google.co.jp/intl/ja/crisisresponse/japanquake2011.html';

			$options['name'][] = 'JALマイル （Japanese）';
			$options['url'][]  = 'https://www.jal.co.jp/shien/';

			$options['name'][] = 'Edy （Japanese）';
			$options['url'][]  = 'http://www.edy.jp/volunteer/touhoku/';

			$options['name'][] = 'DMMクーポン （Japanese）';
			$options['url'][]  = 'http://coupon.dmm.com/deals/dmmbokin/';

			$options['name'][] = 'ニコニコ募金 （Japanese）';
			$options['url'][]  = 'http://blog.nicovideo.jp/niconews/2011/03/011974.html';

			$options['name'][] = 'American Red Cross （English）';
			$options['url'][]  = 'https://american.redcross.org/site/Donation2?idb=0&5052.donation=form1&df_id=5052';

			$options['name'][] = 'PayPal （English）';
			$options['url'][]  = 'https://www.paypal-donations.com/pp-charity/web.us/campaign.jsp?cid=-12';

			$options['name'][] = 'JustGiving （English）';
			$options['url'][]  = 'http://blog.justgiving.com/community/japan-relief-how-to-help/';

			$options['name'][] = 'Amazon.com （English）';
			$options['url'][]  = 'http://www.amazon.com/b/ref=amb_link_355543322_2?ie=UTF8&node=2673660011&pf_rd_m=ATVPDKIKX0DER&pf_rd_s=right-csm-1&pf_rd_r=1S3HDB87J2WENR9ZWV1J&pf_rd_t=101&pf_rd_p=1290864082&pf_rd_i=507846';
		else :
			$options['background'][] = get_option('siteurl') . '/' . PLUGINDIR . '/donation-link-manager/images/background1.png';
			$options['banner'][] = get_option('siteurl') . '/' . PLUGINDIR . '/donation-link-manager/images/banner2.png';

			$options['name'][] = 'American Red Cross (English)';
			$options['url'][]  = 'https://american.redcross.org/site/Donation2?idb=0&5052.donation=form1&df_id=5052';

			$options['name'][] = 'PayPal (English)';
			$options['url'][]  = 'https://www.paypal-donations.com/pp-charity/web.us/campaign.jsp?cid=-12';

			$options['name'][] = 'JustGiving (English)';
			$options['url'][]  = 'http://blog.justgiving.com/community/japan-relief-how-to-help/';

			$options['name'][] = 'Amazon.com (English)';
			$options['url'][]  = 'http://www.amazon.com/b/ref=amb_link_355543322_2?ie=UTF8&node=2673660011&pf_rd_m=ATVPDKIKX0DER&pf_rd_s=right-csm-1&pf_rd_r=1S3HDB87J2WENR9ZWV1J&pf_rd_t=101&pf_rd_p=1290864082&pf_rd_i=507846';
		endif;
		
		update_option('donation_link_manager_data', $options);
	}
		
	function donation_link_manager_admin_scripts() {
		if (strpos($_SERVER['REQUEST_URI'], 'donation-link-manager') !== false ) :
			wp_enqueue_script( 'jquery' );
		endif;
	}
	
	function donation_link_manager_admin_menu() {
		add_options_page(__('Donation Link Manager', 'donation-link-manager'), __('Donation Link Manager', 'donation-link-manager'), 'manage_options', basename(__FILE__), array(&$this, 'donation_link_manager_admin'));
	}
	
	function donation_link_manager_plugin_action_links($links, $file){
		static $this_plugin;

		if( ! $this_plugin ) $this_plugin = plugin_basename(__FILE__);

		if( $file == $this_plugin ){
			$settings_link = '<a href="options-general.php?page=donation-link-manager.php">' . __('Settings', 'donation-link-manager') . '</a>';
			$links = array_merge( array($settings_link), $links);
		}
		return $links;
	}
	
	function donation_link_manager_action() {
		global $wp_version;
		$options = get_option('donation_link_manager_data');

		if ( !empty($_POST['donation_link_manager_donation_link_options_submit']) ) :
			unset($options['name'],$options['url']);
			$j = 0;
			for($i=0;$i<count($_POST["name"]);$i++) {
				if( !empty($_POST["name"][$i]) && !empty($_POST['url'][$i]) ) {
					$options['name'][$j] = $_POST["name"][$i];
					$options['url'][$j] = $_POST["url"][$i];
					$j++;
				}
			}			
			update_option('donation_link_manager_data', $options);
			$message = __('Options updated.', 'donation-link-manager');
			wp_redirect(get_option('siteurl').'/wp-admin/options-general.php?page='.$_REQUEST['page'].'&message=updated');
			exit();
		elseif ( !empty($_POST['donation_link_manager_design_options_submit']) ) :
			unset($options['background'],$options['banner']);
			$j = 0;
			for($i=0;$i<count($_POST["banner"]);$i++) {
				if( !empty($_POST["banner"][$i]) ) {
					$options['background'][$j] = $_POST["background"][$i];
					$options['banner'][$j] = $_POST["banner"][$i];
					$j++;
				}
			}			
			update_option('donation_link_manager_data', $options);
			$message = __('Options updated.', 'donation-link-manager');
			wp_redirect(get_option('siteurl').'/wp-admin/options-general.php?page='.$_REQUEST['page'].'&message=updated');
			exit();
		elseif ( !empty($_POST['donation_link_manager_global_options_submit']) ) :
			unset($options['random'], $options['window']);
			if ( is_array($_POST) ) :
				foreach($_POST as $key => $val) :
					if ( $key != 'donation_link_manager_global_options_submit')
						$options[$key] = $val;
				endforeach;
			endif;
			update_option('donation_link_manager_data', $options);
			wp_redirect(get_option('siteurl').'/wp-admin/options-general.php?page='.$_REQUEST['page'].'&message=updated');
			exit();
		elseif ( !empty($_POST['donation_link_manager_export_options_submit']) ) :
			$filename = "dlm".date('Ymd');
			header("Accept-Ranges: none");
			header("Content-Disposition: attachment; filename=$filename");
			header('Content-Type: application/octet-stream');
			echo maybe_serialize($options);
			exit();
		elseif ( !empty($_POST['donation_link_manager_import_options_submit']) ) :
			if ( is_uploaded_file($_FILES['dlmfile']['tmp_name']) ) :
				ob_start();
				readfile ($_FILES['dlmfile']['tmp_name']);
				$import = ob_get_contents();
				ob_end_clean();
				$import = maybe_unserialize($import);
				update_option('donation_link_manager_data', $import);
				wp_redirect(get_option('siteurl').'/wp-admin/options-general.php?page='.$_REQUEST['page'].'&message=imported');
				exit();
			endif;
		elseif ( !empty($_POST['donation_link_manager_reset_options_submit']) ) :
			$this->install_donation_link_manager_data($_REQUEST['wplang']);
			wp_redirect(get_option('siteurl').'/wp-admin/options-general.php?page='.$_REQUEST['page'].'&message=reset');
			exit();
		elseif ( !empty($_POST['donation_link_manager_delete_options_submit']) ) :
			delete_option('donation_link_manager_data');
			wp_redirect(get_option('siteurl').'/wp-admin/options-general.php?page='.$_REQUEST['page'].'&message=deleted');
			exit();
		endif;
	}
	
	function donation_link_manager_admin() {
		global $current_user, $wp_version;

		$options = get_option('donation_link_manager_data');
		if( empty($options) ) $options = array();
		
		if ( !empty($_GET['message']) && $_GET['message'] == 'updated' )
			$message = __('Options updated.', 'donation-link-manager');
		if ( !empty($_GET['message']) && $_GET['message'] == 'imported' )
			$message = __('Options imported.', 'donation-link-manager');
		if ( !empty($_GET['message']) && $_GET['message'] == 'reset' )
			$message = __('Options reset.', 'donation-link-manager');
		if ( !empty($_GET['message']) && $_GET['message'] == 'deleted' )
			$message = __('Options deleted.', 'donation-link-manager');
?>

<?php if ( !empty($message) ) : ?>
<div id="message" class="updated"><p><?php echo $message; ?></p></div>
<?php endif; ?>
<div class="wrap">
<div id="icon-plugins" class="icon32"><br/></div>
<h2><?php _e('Donation Link Manager', 'donation-link-manager'); ?></h2>

<br class="clear"/>

<div id="poststuff" style="margin-top:10px;">
<div class="postbox closed">
<div class="handlediv" title="<?php _e('Click to toggle', 'donation-link-manager'); ?>"><br /></div>
<h3><?php _e('Donation Link Options', 'donation-link-manager'); ?></h3>
<div class="inside">
<form method="post">
<table class="form-table" style="margin-bottom:5px;">
<tbody>
<?php
	if ( isset($options['name']) ) $count = count($options['name']);
	else $count = 0;
	for ( $i = 0; $i < $count+1; $i++ ) :
?>
<tr>
<td style="width:20px;">#<?php echo ($i+1); ?></td>
<td>
<p><label><?php _e('Donation Name:', 'donation-link-manager'); ?></label> 
<input type="text" name="name[<?php echo $i; ?>]" class="large-text" value="<?php if ( !empty($options['name'][$i]) ) echo esc_attr($options['name'][$i]); ?>" /><br />
<label><?php _e('Link URL:', 'donation-link-manager'); ?></label> 
<input type="text" name="url[<?php echo $i; ?>]" class="large-text" value="<?php if ( !empty($options['url'][$i]) ) echo esc_attr($options['url'][$i]); ?>" /></p>
</td></tr>
<?php
	endfor;
?>
<tr><td colspan="2">
<p><input type="submit" name="donation_link_manager_donation_link_options_submit" value="<?php _e('Update Options &raquo;', 'donation-link-manager'); ?>" class="button-primary" /></p>
</td></tr>
</tbody>
</table>
</form>
</div>
</div>

<div class="postbox closed">
<div class="handlediv" title="<?php _e('Click to toggle', 'donation-link-manager'); ?>"><br /></div>
<h3><?php _e('Design Options', 'donation-link-manager'); ?></h3>
<div class="inside">
<form method="post">
<table class="form-table" style="margin-bottom:5px;">
<tbody>
<?php
	if ( isset($options['banner']) ) $count = count($options['banner']);
	else $count = 0;
	for ( $i = 0; $i < $count+1; $i++ ) :
?>
<tr>
<td style="width:20px;">#<?php echo ($i+1); ?></td>
<td>
<p><label><?php _e('Background URL:', 'donation-link-manager'); ?></label> 
<input type="text" name="background[<?php echo $i; ?>]" class="large-text" value="<?php if ( !empty($options['background'][$i]) ) echo esc_attr($options['background'][$i]); ?>" /><br />
<label><?php _e('Banner URL:', 'donation-link-manager'); ?></label> 
<input type="text" name="banner[<?php echo $i; ?>]" class="large-text" value="<?php if ( !empty($options['banner'][$i]) ) echo esc_attr($options['banner'][$i]); ?>" /></p>
</td></tr>
<?php
	endfor;
?>
<tr><td colspan="2">
<p><input type="submit" name="donation_link_manager_design_options_submit" value="<?php _e('Update Options &raquo;', 'donation-link-manager'); ?>" class="button-primary" /></p>
</td></tr>
</tbody>
</table>
</form>
</div>
</div>

<div class="postbox closed">
<div class="handlediv" title="<?php _e('Click to toggle', 'donation-link-manager'); ?>"><br /></div>
<h3><?php _e('Global Options', 'donation-link-manager'); ?></h3>
<div class="inside">
<form method="post">
<table class="form-table" style="margin-bottom:5px;">
<tbody>
<?php /*
<tr>
<td style="width:100px;"><label for="position"><?php _e('Banner Position', 'donation-link-manager'); ?></label></td>
<td><select name="position" id="position">
<option value="top" <?php selected('top', $options['position']); ?>><?php _e('Top', 'donation-link-manager'); ?></option>
<option value="bottom" <?php selected('bottom', $options['position']); ?>><?php _e('Bottom', 'donation-link-manager'); ?></option>
</select></td>
</tr>
*/ ?>
<tr>
<td style="width:100px;"><label for="design"><?php _e('Design', 'donation-link-manager'); ?></label></td>
<td><select name="design">
<?php
	for ( $i=0; $i<count($options['banner']); $i++ ) :
?>
<option value="<?php echo $i; ?>" <?php selected($i, $options['design']); ?>><?php _e('Design', 'donation-link-manager'); ?> #<?php echo ($i+1); ?></option>
<?php
	endfor;
?>
</select></td>
</tr>
<tr>
<td style="width:100px;"><label for="random"><?php _e('Random Design', 'donation-link-manager'); ?></label></td>
<td><input type="checkbox" name="random" id="random" value="1" <?php if ( isset($options['random']) ) checked(1, $options['random']); ?> /></td>
</tr>
<tr>
<td style="width:100px;"><label for="height"><?php _e('Banner Height', 'donation-link-manager'); ?></label></td>
<td><input type="text" name="height" id="height" class="small-text" value="<?php if ( isset($options['height']) ) echo esc_attr($options['height']); ?>" /> px</td>
</tr>
<tr>
<td style="width:100px;"><label for="width"><?php _e('Banner Width', 'donation-link-manager'); ?></label></td>
<td><input type="text" name="width" id="width" class="small-text" value="<?php if ( isset($options['width']) ) echo esc_attr($options['width']); ?>" /> px</td>
</tr>
<tr>
<td style="width:100px;"><label for="position"><?php _e('Banner Position', 'donation-link-manager'); ?></label></td>
<td><select name="position" id="position">
<option value="center" <?php if ( isset($options['position']) ) selected('center', $options['position']); ?>><?php _e('Center', 'donation-link-manager'); ?></option>
<option value="left" <?php if ( isset($options['position']) ) selected('left', $options['position']); ?>><?php _e('Left', 'donation-link-manager'); ?></option>
<option value="right" <?php if ( isset($options['position']) ) selected('right', $options['position']); ?>><?php _e('Right', 'donation-link-manager'); ?></option>
</select></td>
</tr>
<tr>
<td style="width:100px;"><label for="window"><?php _e('New Window', 'donation-link-manager'); ?></label></td>
<td><input type="checkbox" name="window" id="window" value="1" <?php if ( isset($options['window']) ) checked(1, $options['window']); ?> /></td>
</tr>
<tr>
<td style="width:100px;"><label for="css"><?php _e('Extra CSS', 'donation-link-manager'); ?></label></td>
<td><textarea name="css" id="css" class="large-text"><?php if ( isset($options['css']) ) echo stripslashes($options['css']); ?></textarea></td>
</tr>
<tr>
<td style="width:100px;"><label for="selecttext"><?php _e('Select Box Text', 'donation-link-manager'); ?></label></td>
<td><input type="text" name="selecttext" id="selecttext" class="regular-text" value="<?php if ( isset($options['selecttext']) ) echo esc_attr($options['selecttext']); ?>" /></td>
</tr>
<tr><td>
<p><input type="submit" name="donation_link_manager_global_options_submit" value="<?php _e('Update Options &raquo;', 'donation-link-manager'); ?>" class="button-primary" /></p>
</td></tr>
</tbody>
</table>
</form>
</div>
</div>

<div class="postbox closed">
<div class="handlediv" title="<?php _e('Click to toggle', 'donation-link-manager'); ?>"><br /></div>
<h3><?php _e('Export Options', 'donation-link-manager'); ?></h3>
<div class="inside">
<form method="post">
<table class="form-table" style="margin-bottom:5px;">
<tbody>
<tr><td>
<p><input type="submit" name="donation_link_manager_export_options_submit" value="<?php _e('Export Options &raquo;', 'donation-link-manager'); ?>" class="button-primary" /></p>
</td></tr>
</tbody>
</table>
</form>
</div>
</div>

<div class="postbox closed">
<div class="handlediv" title="<?php _e('Click to toggle', 'donation-link-manager'); ?>"><br /></div>
<h3><?php _e('Import Options', 'donation-link-manager'); ?></h3>
<div class="inside">
<form method="post" action="?page=donation-link-manager.php" enctype="multipart/form-data" onsubmit="return confirm('<?php _e('Are you sure to import options? Options you set will be overwritten.', 'donation-link-manager'); ?>');">
<table class="form-table" style="margin-bottom:5px;">
<tbody>
<tr><td>
<p><input type="file" name="dlmfile" /> <input type="submit" name="donation_link_manager_import_options_submit" value="<?php _e('Import Options &raquo;', 'donation-link-manager'); ?>" class="button-primary" /></p>
</td></tr>
</tbody>
</table>
</form>
</div>
</div>

<div class="postbox closed">
<div class="handlediv" title="<?php _e('Click to toggle', 'donation-link-manager'); ?>"><br /></div>
<h3><?php _e('Reset Options', 'donation-link-manager'); ?></h3>
<div class="inside">
<form method="post" action="?page=donation-link-manager.php" onsubmit="return confirm('<?php _e('Are you sure to reset options? Options you set will be reset to the default settings.', 'donation-link-manager'); ?>');">
<table class="form-table" style="margin-bottom:5px;">
<tbody>
<tr><td>
<p><select name="wplang">
<option value="ja"><?php _e('Japanese', 'donation-link-manager'); ?></option>
<option value=""><?php _e('Others', 'donation-link-manager'); ?></option>
</select> 
<input type="submit" name="donation_link_manager_reset_options_submit" value="<?php _e('Reset Options &raquo;', 'donation-link-manager'); ?>" class="button-primary" /></p>
</td></tr>
</tbody>
</table>
</form>
</div>
</div>

<div class="postbox closed">
<div class="handlediv" title="<?php _e('Click to toggle', 'donation-link-manager'); ?>"><br /></div>
<h3><?php _e('Delete Options', 'donation-link-manager'); ?></h3>
<div class="inside">
<form method="post" action="?page=donation-link-manager.php" onsubmit="return confirm('<?php _e('Are you sure to delete options? Options you set will be deleted.', 'donation-link-manager'); ?>');">
<table class="form-table" style="margin-bottom:5px;">
<tbody>
<tr><td>
<p><input type="submit" name="donation_link_manager_delete_options_submit" value="<?php _e('Delete Options &raquo;', 'donation-link-manager'); ?>" class="button-primary" /></p>
</td></tr>
</tbody>
</table>
</form>
</div>
</div>

</div>

<script type="text/javascript">
// <![CDATA[
<?php if ( version_compare( substr($wp_version, 0, 3), '2.7', '<' ) ) { ?>
jQuery('.postbox h3').prepend('<a class="togbox">+</a> ');
<?php } ?>
jQuery('.postbox div.handlediv').click( function() { jQuery(jQuery(this).parent().get(0)).toggleClass('closed'); } );
jQuery('.postbox h3').click( function() { jQuery(jQuery(this).parent().get(0)).toggleClass('closed'); } );
jQuery('.postbox.close-me').each(function(){
jQuery(this).addClass("closed");
});
//-->
</script>

</div>
<?php
	}
	
	function donation_link_manager_wp_footer() {
		$options = get_option('donation_link_manager_data');
		
		if ( empty($options) ) return;
		
		switch( $options['position'] ) :
			case 'left' : $position = 'auto auto auto 0'; break;
			case 'right' : $position = 'auto 0 auto auto'; break;
			default : $position = 'auto';
		endswitch;
		
		if ( !empty($options['random']) ) $design = rand(0, count($options['design']));
		else $design = $options['design'];
?>
<style type="text/css">
html { margin-top: <?php echo $options['height']; ?>px !important; }
* html body { margin-top: <?php echo $options['height']; ?>px !important; }
#dlmbar { position:absolute; top:0; left:0; margin:0; padding:0; height:<?php echo $options['height']; ?>px; width:100%; text-align:center; <?php if ( !empty($options['background'][$design]) ) : echo 'background:url('.$options['background'][$design].') center repeat;'; endif; ?> }
#dlmcontent { width:<?php echo $options['width']; ?>px; margin:<?php echo $position; ?>; padding:0; line-height:<?php echo $options['height']; ?>px; position:relative; }
#dlmcontent a { width:<?php echo $options['width']; ?>px; height:<?php echo $options['height']; ?>px; display:block; outline:none; float:left; <?php if ( !empty($options['banner'][$design]) ) : echo 'background:url('.$options['banner'][$design].') center no-repeat;'; endif; ?> }
#dlmcontent a:hover { text-decoration:none; }
#dlmcontent div { margin:0; margin-top:-<?php echo $options['height']; ?>px; float:right; padding:0; }
* html body #dlmcontent div { margin-top:-<?php echo (int)($options['height']/1.5); ?>px; }
#dlmurl { font-size:120%; width:250px; }
<?php if ( !empty($options['css']) ) echo $options['css']."\n"; ?>
</style>
<div id="dlmbar">
<div id="dlmcontent">
<a href="<?php echo esc_attr($options['url'][0]); ?>" onclick="var url = document.getElementById('dlmurl').value; <?php if ( !empty($options['window']) ) : ?>if(url){window.open(url);}<?php else : ?>if(url){location.href=url;}<?php endif; ?>"> </a>
<div>
<select id="dlmurl" onchange="var url = document.getElementById('dlmurl').value; <?php if ( !empty($options['window']) ) : ?>if(url){window.open(url);}<?php else : ?>if(url){location.href=url;}<?php endif; ?>">
<option value=""><?php if ( !empty($options['selecttext']) ) : echo esc_attr($options['selecttext']); else : _e('Donate to:', 'donation-link-manager'); endif; ?></option>
<?php 
		for ( $i=0; $i<count($options['name']); $i++ ) :
?>
<option value="<?php echo esc_attr($options['url'][$i]); ?>"><?php echo $options['name'][$i]; ?></option>
<?php
		endfor;
?>
</select>
</div>
</div>
</div>
<?php	
	}
}
$donation_link_manager = new donation_link_manager();
?>